Software Version - Nautobot Documentation

Skip to content

# Software Version

Added in version 2.2.0

This model will replace the `SoftwareLCM` model from Nautobot Device Lifecycle Management

Software versions are used to track attributes that may apply to multiple software images. A software version must be assigned to a platform and can optionally have a release date, end of support date, documentation url and flags that indicate if the version is a pre-release or a long term support version.